Objective Templates (ABCs)
~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: objectives.obj_func
..    :members: objectives/obj_func

.. autoclass:: obj_func
   :member-order: bysource
   :members:

   .. automethod:: __init__
   .. automethod:: __call__

Objective Function Library
~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: objectives.obj_lib
..    :members: objectives/obj_lib

.. autoclass:: single_sim_out
   :member-order: bysource
   :members:

   .. automethod:: __init__
   .. automethod:: __call__

.. autoclass:: sos_sim_out
   :member-order: bysource
   :members:

   .. automethod:: __init__
   .. automethod:: __call__

.. autoclass:: sum_sim_out
   :member-order: bysource
   :members:

   .. automethod:: __init__
   .. automethod:: __call__
